@@ -4,17 +4,15 @@
 from __future__ import annotations
 
 from abc import ABCMeta
-from configparser import ConfigParser
 
 import httpx
 
+from livechat.config import CONFIG
 from livechat.utils.helpers import prepare_payload
 from livechat.utils.httpx_logger import HttpxLogger
 
-config = ConfigParser()
-config.read('configs/main.ini')
-stable_version = config.get('api', 'stable')
-api_url = config.get('api', 'url')
+stable_version = CONFIG.get('stable')
+api_url = CONFIG.get('url')
 
 
 class ConfigurationApi:
