@@ -8,9 +8,13 @@ from abc import ABCMeta
 
 import httpx
 
+from livechat.config import CONFIG
 from livechat.utils.helpers import prepare_payload
 from livechat.utils.httpx_logger import HttpxLogger
 
+stable_version = CONFIG.get('stable')
+api_url = CONFIG.get('url')
+
 
 # pylint: disable=R0903
 class CustomerWeb:
@@ -19,18 +23,18 @@ class CustomerWeb:
     @staticmethod
     def get_client(license_id: int = None,
                    access_token: str = None,
-                   version: str = '3.3',
-                   base_url: str = 'api.livechatinc.com',
+                   version: str = stable_version,
+                   base_url: str = api_url,
                    http2: bool = False,
                    organization_id: str = None) -> CustomerWebInterface:
         ''' Returns client for specific API version.
 
             Args:
-                license_id (int): License ID. Required to use API v3.3.
+                license_id (int): License ID. Required to use for API version <= 3.3.
                 token (str): Full token with type (Bearer/Basic) that will be
-                                used as `Authorization` header in requests to API.
-                version (str): API's version. Defaults to `3.3`.
-                base_url (str): API's base url. Defaults to `api.livechatinc.com`.
+                             used as `Authorization` header in requests to API.
+                version (str): API's version. Defaults to the stable version of API.
+                base_url (str): API's base url. Defaults to API's production URL.
                 http2 (bool): A boolean indicating if HTTP/2 support should be
                               enabled. Defaults to `False`.
                 organization_id (str): Organization ID, replaced license ID in v3.4.
@@ -42,7 +46,11 @@ class CustomerWeb:
             Raises:
                 ValueError: If the specified version does not exist.
         '''
-        client = {'3.3': CustomerWeb33, '3.4': CustomerWeb34}.get(version)
+        client = {
+            '3.3': CustomerWeb33,
+            '3.4': CustomerWeb34,
+            '3.5': CustomerWeb35,
+        }.get(version)
         client_kwargs = {
             '3.3': {
                 'license_id': license_id,
@@ -57,7 +65,14 @@ class CustomerWeb:
                 'version': version,
                 'url': base_url,
                 'http2': http2
-            }
+            },
+            '3.5': {
+                'organization_id': organization_id,
+                'access_token': access_token,
+                'version': version,
+                'url': base_url,
+                'http2': http2
+            },
         }.get(version)
         if client:
             return client(**client_kwargs)
@@ -66,8 +81,13 @@ class CustomerWeb:
 
 class CustomerWebInterface(metaclass=ABCMeta):
     ''' Main class containing API methods. '''
-    def __init__(self, access_token: str, version: str, base_url: str,
-                 http2: bool) -> CustomerWebInterface:
+    def __init__(self,
+                 access_token: str,
+                 version: str,
+                 base_url: str,
+                 http2: bool,
+                 proxies=None,
+                 verify: bool = True) -> CustomerWebInterface:
         logger = HttpxLogger()
         self.api_url = f'https://{base_url}/v{version}/customer/action'
         if all([access_token, isinstance(access_token, str)]):
@@ -77,7 +97,9 @@ class CustomerWebInterface(metaclass=ABCMeta):
                 event_hooks={
                     'request': [logger.log_request],
                     'response': [logger.log_response]
-                })
+                },
+                proxies=proxies,
+                verify=verify)
         else:
             raise ValueError(
                 'Incorrect or missing `access_token` argument (should be of type str.)'
@@ -662,69 +684,6 @@ class CustomerWebInterface(metaclass=ABCMeta):
             json=payload,
             headers=headers)
 
-    def list_license_properties(self,
-                                namespace: str = None,
-                                name: str = None,
-                                payload: dict = None,
-                                headers: dict = None) -> httpx.Response:
-        ''' Returns the properties of a given license. It only returns the properties a Customer has access to.
-
-            Args:
-                namespace (str): Property namespace to retrieve.
-                name (str): Property name.
-                payload (dict): Custom payload to be used as request's data.
-                headers (dict): Custom headers to be used with session headers.
-                                They will be merged with session-level values that are set,
-                                however, these method-level parameters will not be persisted across requests.
-
-            Returns:
-                httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request. '''
-        if payload is None:
-            payload = {}
-        params = {}
-        if namespace:
-            params['namespace'] = namespace
-        if name:
-            params['name'] = name
-        return self.session.post(f'{self.api_url}/list_license_properties',
-                                 json=payload,
-                                 params=params,
-                                 headers=headers)
-
-    def list_group_properties(self,
-                              group_id: int = None,
-                              namespace: str = None,
-                              name: str = None,
-                              payload: dict = None,
-                              headers: dict = None) -> httpx.Response:
-        ''' Returns the properties of a given group. It only returns the properties a Customer has access to.
-            Args:
-                group_id (int): ID of the group you want to return the properties of.
-                namespace (str): Property namespace to retrieve.
-                name (str): Property name.
-                payload (dict): Custom payload to be used as request's data.
-                headers (dict): Custom headers to be used with session headers.
-                                They will be merged with session-level values that are set,
-                                however, these method-level parameters will not be persisted across requests.
-
-            Returns:
-                httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request. '''
-        if payload is None:
-            payload = {}
-        params = {}
-        if namespace:
-            params['namespace'] = namespace
-        if name:
-            params['name'] = name
-        if group_id:
-            params['id'] = str(group_id)
-        return self.session.post(f'{self.api_url}/list_group_properties',
-                                 json=payload,
-                                 params=params,
-                                 headers=headers)
-
 # Customers
 
     def get_customer(self,
@@ -1176,3 +1135,82 @@ class CustomerWeb34(CustomerWebInterface):
                                  json=payload,
                                  params=params,
                                  headers=headers)
+
+
+class CustomerWeb35(CustomerWebInterface):
+    ''' Customer API version 3.5 class. '''
+    def __init__(self, organization_id: str, access_token: str, version: str,
+                 url: str, http2: bool) -> CustomerWeb35:
+        super().__init__(access_token, version, url, http2)
+        if isinstance(organization_id, str):
+            self.organization_id = organization_id
+            self.query_string = f'?organization_id={organization_id}'
+        else:
+            raise ValueError(
+                'Incorrect or missing `organization_id` argument (should be of type str.)'
+            )
+
+    def list_license_properties(self,
+                                namespace: str = None,
+                                name: str = None,
+                                payload: dict = None,
+                                headers: dict = None) -> httpx.Response:
+        ''' Returns the properties of a given license. It only returns the properties a Customer has access to.
+
+            Args:
+                namespace (str): Property namespace to retrieve.
+                name (str): Property name.
+                payload (dict): Custom payload to be used as request's data.
+                headers (dict): Custom headers to be used with session headers.
+                                They will be merged with session-level values that are set,
+                                however, these method-level parameters will not be persisted across requests.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server’s response to an HTTP request. '''
+        if payload is None:
+            payload = {}
+        params = {}
+        if namespace:
+            params['namespace'] = namespace
+        if name:
+            params['name'] = name
+        params['organization_id'] = self.organization_id
+        return self.session.post(f'{self.api_url}/list_license_properties',
+                                 json=payload,
+                                 params=params,
+                                 headers=headers)
+
+    def list_group_properties(self,
+                              group_id: int = None,
+                              namespace: str = None,
+                              name: str = None,
+                              payload: dict = None,
+                              headers: dict = None) -> httpx.Response:
+        ''' Returns the properties of a given group. It only returns the properties a Customer has access to.
+            Args:
+                group_id (int): ID of the group you want to return the properties of.
+                namespace (str): Property namespace to retrieve.
+                name (str): Property name.
+                payload (dict): Custom payload to be used as request's data.
+                headers (dict): Custom headers to be used with session headers.
+                                They will be merged with session-level values that are set,
+                                however, these method-level parameters will not be persisted across requests.
+
+            Returns:
+                httpx.Response: The Response object from `httpx` library,
+                                which contains a server’s response to an HTTP request. '''
+        if payload is None:
+            payload = {}
+        params = {}
+        if namespace:
+            params['namespace'] = namespace
+        if name:
+            params['name'] = name
+        if group_id:
+            params['id'] = str(group_id)
+        params['organization_id'] = self.organization_id
+        return self.session.post(f'{self.api_url}/list_group_properties',
+                                 json=payload,
+                                 params=params,
+                                 headers=headers)
